@@ -47,6 +47,15 @@
 #endif
 
 
+/*
+** Define language for error messages
+*/
+
+#define	ENGLISH
+/*#define	GERMAN */
+
+
+
 /*
 ** Max length for a path name
 */
