@@ -13,7 +13,7 @@ echo
 echo	"# Make rules for building $obj"
 echo
 echo	"$obj : $src $deps"
-echo	'	$(CC) $(CC_FLAGS)'" -c -o $obj $src"
+echo	'	$(CC) $(CC_FLAGS)'" -c $src"
 echo
 echo	"clean ::"
 echo	"	rm -f $obj $base.lint"
