@@ -107,7 +107,7 @@ int msqlLoadAcl(verbose)
 	/*
 	** Open the acl file
 	*/
-	(void)sprintf(path,"%s/msql.acl", INST_DIR);
+	(void)sprintf(path,"%s/msql.acl", msqlHomeDir);
 	fp = fopen(path,"r");
 	if (!fp)
 	{
@@ -755,3 +755,33 @@ int msqlCheckPerms(access)
 {
 	return( accessPerms & access);
 }
+
+
+
+int msqlCheckLocal(info)
+	cinfo_t	*info;
+{
+	char 	*host,
+		*user;
+	struct  sockaddr *local, 
+		*remote;
+	acl_t	*curAcl;
+	acc_t	*curAcc;
+	int	res,
+		perms;
+
+
+	host = info->host;
+	user = info->user;
+	local = (struct sockaddr *)&(info->local);
+	remote = (struct sockaddr *)&(info->remote);
+	if ( (!info->host || strcmp(host,"localhost") == 0) &&
+	     strcmp(info->user,ROOT) == 0)
+	{
+		return(1);
+	}
+	else
+	{
+		return(0);
+	}
+}
