@@ -43,6 +43,7 @@
 #endif
 
 #include "msql_priv.h"
+#include "errmsg.h"
 
 #define _LIB_SOURCE
 #include "msql.h"
@@ -351,8 +352,8 @@ static m_fdata *tableToFieldList(data)
 
 		curField->field.table = (char *)strdup(curRow->data[0]);
 		curField->field.name = (char *)strdup(curRow->data[1]);
-		curField->field.type = atoi(curRow->data[2]);
-		curField->field.length = atoi(curRow->data[3]);
+		curField->field.type = atoi((char*)curRow->data[2]);
+		curField->field.length = atoi((char*)curRow->data[3]);
 		curField->field.flags = 0;
 		if (*curRow->data[4] == 'Y')
 			curField->field.flags |= NOT_NULL_FLAG;
@@ -376,18 +377,21 @@ static m_fdata *tableToFieldList(data)
 int msqlConnect(host)
 	char	*host;
 {
-	char	*cp;
+	char	*cp,
+		*envVar,
+		*unixPort;
 	struct	sockaddr_in IPaddr;
 
 #ifdef HAVE_SYS_UN_H
 	struct	sockaddr_un UNIXaddr;
 #endif
-
+        struct  servent         *serv_ptr;
 	struct	hostent *hp;
 	u_long	IPAddr;
 	int	opt,
 		version,
-		sock;
+		sock,
+		tcpPort;
 	struct	passwd *pw;
 
 
@@ -414,13 +418,18 @@ int msqlConnect(host)
 	{
 #ifdef HAVE_SYS_UN_H
 		/* Shouldn't get in here with UNIX socks */
+	        unixPort = MSQL_UNIX_ADDR;
+        	if ((envVar = getenv("MSQL_UNIX_PORT")))
+        	{
+                	unixPort = envVar;
+        	}
 		strcpy(hostInfo,"Localhost via UNIX socket");
 		msqlDebug(MOD_API,"Server name = NULL.  Using UNIX sock(%s)\n",
-			MSQL_UNIX_ADDR);
+			unixPort);
 		sock = socket(AF_UNIX,SOCK_STREAM,0);
 		if (sock < 0)
 		{
-			sprintf(msqlErrMsg,"Can't create UNIX socket");
+			sprintf(msqlErrMsg,SOCKET_ERROR);
 			return(-1);
 		}
 		setServerSock(sock);
@@ -430,11 +439,11 @@ int msqlConnect(host)
 
 		(void)bzero(&UNIXaddr,sizeof(UNIXaddr));
 		UNIXaddr.sun_family = AF_UNIX;
-		strcpy(UNIXaddr.sun_path, MSQL_UNIX_ADDR);
+		strcpy(UNIXaddr.sun_path, unixPort);
 		if(connect(sock,(struct sockaddr *) &UNIXaddr, 
 			sizeof(UNIXaddr))<0)
 		{
-			sprintf(msqlErrMsg,"Can't connect to local MSQL server");
+			sprintf(msqlErrMsg,CONNECTION_ERROR);
 			close(sock);
 			return(-1);
 		}
@@ -442,13 +451,23 @@ int msqlConnect(host)
 	}
 	else
 	{
+	        tcpPort = MSQL_PORT;
+        	if ((serv_ptr = getservbyname("msql", "tcp")))
+        	{
+                	tcpPort = serv_ptr->s_port;
+        	}
+        	if ((envVar = getenv("MSQL_TCP_PORT")))
+        	{
+                	tcpPort = atoi(envVar);
+        	}
+
 		sprintf(hostInfo,"%s via TCP/IP",host);
 		msqlDebug(MOD_API,"Server name = %s.  Using TCP sock (%d)\n",
-			host, MSQL_PORT);
+			host, tcpPort);
 		sock = socket(AF_INET,SOCK_STREAM,0);
 		if (sock < 0)
 		{
-			sprintf(msqlErrMsg,"Can't create IP socket");
+			sprintf(msqlErrMsg,IPSOCK_ERROR);
 			return(-1);
 		}
 		setServerSock(sock);
@@ -473,19 +492,18 @@ int msqlConnect(host)
 			if (!hp)
 			{
 				sprintf(msqlErrMsg,
-					"Unknown MSQL Server Host (%s)",
+					UNKNOWN_HOST,
 					host);
 				close(sock);
 				return(-1);
 			}
 			bcopy(hp->h_addr,&IPaddr.sin_addr, hp->h_length);
 		}
-		IPaddr.sin_port = htons(MSQL_PORT);
+		IPaddr.sin_port = htons(tcpPort);
 		if(connect(sock,(struct sockaddr *) &IPaddr, 
 			sizeof(IPaddr))<0)
 		{
-			sprintf(msqlErrMsg,"Can't connect to MSQL server on %s",
-				host);
+			sprintf(msqlErrMsg,CONN_HOST_ERROR, host);
 			perror("Connect");
 			close(sock);
 			return(-1);
@@ -502,7 +520,7 @@ int msqlConnect(host)
 	if(readPkt(sock) <= 0)
 	{
 		closeServer(sock);
-		strcpy(msqlErrMsg,"MSQL server has gone away");
+		strcpy(msqlErrMsg,SERVER_GONE_ERROR);
 		return(-1);
 	}
 
@@ -522,7 +540,7 @@ int msqlConnect(host)
 		}
 		else
 		{
-			strcpy(msqlErrMsg,"Unknown MSQL error");
+			strcpy(msqlErrMsg,UNKNOWN_ERROR);
 		}
 		closeServer(sock);
 		return(-1);
@@ -532,16 +550,14 @@ int msqlConnect(host)
 	cp = (char *)index(packet,':');
 	if (!cp)
 	{
-		strcpy(msqlErrMsg,"Bad packet received from server");
+		strcpy(msqlErrMsg,PACKET_ERROR);
 		closeServer(sock);
 		return(-1);
 	}
 	version = atoi(cp + 1);
 	if (version != PROTOCOL_VERSION) 
 	{
-		sprintf(msqlErrMsg,
-		   "Protocol mismatch. Server Version = %d Client Version = %d",
-			version, PROTOCOL_VERSION);
+		sprintf(msqlErrMsg, VERSION_ERROR, version, PROTOCOL_VERSION);
 		closeServer(sock);
 		return(-1);
 	}
@@ -570,7 +586,7 @@ int msqlConnect(host)
 	pw = getpwuid(getuid());
 	if (!pw)
 	{
-		strcpy(msqlErrMsg,"Can't find your username. Who are you?");
+		strcpy(msqlErrMsg,USERNAME_ERROR);
 		closeServer(sock);
 		return(-1);
 	}
@@ -580,7 +596,7 @@ int msqlConnect(host)
 	if(readPkt(sock) <= 0)
 	{
 		closeServer(sock);
-		strcpy(msqlErrMsg,"MSQL server has gone away");
+		strcpy(msqlErrMsg,SERVER_GONE_ERROR);
 		return(-1);
 	}
 
@@ -601,7 +617,7 @@ int msqlConnect(host)
 		}
 		else
 		{
-			strcpy(msqlErrMsg,"Unknown MSQL error");
+			strcpy(msqlErrMsg,UNKNOWN_ERROR);
 		}
 		closeServer(sock);
 		return(-1);
@@ -646,7 +662,7 @@ int msqlSelectDB(sock,db)
 	if(readPkt(sock) <= 0)
 	{
 		closeServer(sock);
-		strcpy(msqlErrMsg,"MSQL server has gone away");
+		strcpy(msqlErrMsg,SERVER_GONE_ERROR);
 		return(-1);
 	}
 
@@ -667,7 +683,7 @@ int msqlSelectDB(sock,db)
 		}
 		else
 		{
-			strcpy(msqlErrMsg,"Unknown MSQL error");
+			strcpy(msqlErrMsg,UNKNOWN_ERROR);
 		}
 		return(-1);
 	}
@@ -862,7 +878,7 @@ int msqlQuery(sock,q)
 	if(readPkt(sock) <= 0)
 	{
 		closeServer(sock);
-		strcpy(msqlErrMsg,"MSQL server has gone away");
+		strcpy(msqlErrMsg,SERVER_GONE_ERROR);
 		return(-1);
 	}
 
@@ -882,7 +898,7 @@ int msqlQuery(sock,q)
 		}
 		else
 		{
-			strcpy(msqlErrMsg,"Unknown MSQL error");
+			strcpy(msqlErrMsg,UNKNOWN_ERROR);
 		}
 		return(-1);
 	}
@@ -955,7 +971,7 @@ int readQueryData(sock)
 	if (readPkt(sock) <= 0)
 	{
 		closeServer(sock);
-		strcpy(msqlErrMsg,"MSQL server has gone away");
+		strcpy(msqlErrMsg,SERVER_GONE_ERROR);
 		return(-1);
 	}
 
@@ -972,7 +988,7 @@ int readQueryData(sock)
 			}	
 			else
 			{
-				strcpy(msqlErrMsg,"Unknown mSQL error");
+				strcpy(msqlErrMsg,UNKNOWN_ERROR);
 			}
 			return(-1);
 		}
@@ -989,7 +1005,7 @@ int readQueryData(sock)
 		msqlDebug(MOD_MALLOC,"Query data row - malloc @ %X of %d\n",
 			cur, sizeof(m_data));
 		(void)bzero(cur,sizeof(m_data));
-		cur->data = (char **)malloc(numFields * sizeof(char *));
+		cur->data = (u_char **)malloc(numFields * sizeof(char *));
 		(void)bzero(cur->data,numFields * sizeof(char *));
 		cur->width = numFields;
 		off = 0;
@@ -998,17 +1014,25 @@ int readQueryData(sock)
 		{
 			len = atoi(cp);
 			cp = (char *)index(cp,':');
-			cur->data[off] = (char *)malloc(len+1);
-			(void)bzero(cur->data[off],len+1);
-			(void)bcopy(cp+1,cur->data[off],len);
-			cp += len + 1;
+			if (len == -1)
+			{
+				cur->data[off] = (u_char *)NULL;
+				cp++;
+			}
+			else
+			{
+				cur->data[off] = (u_char *)malloc(len+1);
+				(void)bzero(cur->data[off],len+1);
+				(void)bcopy(cp+1,cur->data[off],len);
+				cp += len + 1;
+			}
 			off++;
 		}
 
 		if (readPkt(sock) <= 0)
 		{
 			closeServer(sock);
-			strcpy(msqlErrMsg,"MSQL server has gone away");
+			strcpy(msqlErrMsg,SERVER_GONE_ERROR);
 			return(-1);
 		}
 	}
@@ -1184,7 +1208,7 @@ int msqlCreateDB(sock,DB)
 	if(readPkt(sock) <= 0)
 	{
 		closeServer(sock);
-		strcpy(msqlErrMsg,"MSQL server has gone away");
+		strcpy(msqlErrMsg,SERVER_GONE_ERROR);
 		return(-1);
 	}
 
@@ -1203,7 +1227,7 @@ int msqlCreateDB(sock,DB)
 		}
 		else
 		{
-			strcpy(msqlErrMsg,"Unknown MSQL error");
+			strcpy(msqlErrMsg,UNKNOWN_ERROR);
 		}
 		return(-1);
 	}
@@ -1223,7 +1247,7 @@ int msqlDropDB(sock,DB)
 	if(readPkt(sock) <= 0)
 	{
 		closeServer(sock);
-		strcpy(msqlErrMsg,"MSQL server has gone away");
+		strcpy(msqlErrMsg,SERVER_GONE_ERROR);
 		return(-1);
 	}
 
@@ -1242,7 +1266,7 @@ int msqlDropDB(sock,DB)
 		}
 		else
 		{
-			strcpy(msqlErrMsg,"Unknown MSQL error");
+			strcpy(msqlErrMsg,UNKNOWN_ERROR);
 		}
 		return(-1);
 	}
@@ -1262,7 +1286,7 @@ int msqlShutdown(sock)
 	if(readPkt(sock) <= 0)
 	{
 		closeServer(sock);
-		strcpy(msqlErrMsg,"MSQL server has gone away");
+		strcpy(msqlErrMsg,SERVER_GONE_ERROR);
 		return(-1);
 	}
 
@@ -1281,7 +1305,7 @@ int msqlShutdown(sock)
 		}
 		else
 		{
-			strcpy(msqlErrMsg,"Unknown MSQL error");
+			strcpy(msqlErrMsg,UNKNOWN_ERROR);
 		}
 		return(-1);
 	}
@@ -1302,7 +1326,7 @@ int msqlReloadAcls(sock)
 	if(readPkt(sock) <= 0)
 	{
 		closeServer(sock);
-		strcpy(msqlErrMsg,"MSQL server has gone away");
+		strcpy(msqlErrMsg,SERVER_GONE_ERROR);
 		return(-1);
 	}
 
@@ -1321,7 +1345,7 @@ int msqlReloadAcls(sock)
 		}
 		else
 		{
-			strcpy(msqlErrMsg,"Unknown MSQL error");
+			strcpy(msqlErrMsg,UNKNOWN_ERROR);
 		}
 		return(-1);
 	}
