@@ -101,7 +101,7 @@ handleQuery(sock, q)
 	char	*q;
 {
 	char	*nq,
-		sepBuf[2048];
+		sepBuf[5 * 1024];
 	int	off,
 		length;
 	m_result *result;
@@ -241,8 +241,16 @@ handleQuery(sock, q)
 						curField->length);
 				break;
 			}
-			printf(" %s",cur[off]);
-			fill(strlen(cur[off]),length,' ');
+			if (cur[off])
+			{
+				printf(" %s",cur[off]);
+				fill(strlen(cur[off]),length,' ');
+			}
+			else
+			{
+				printf(" NULL");
+				fill(4,length,' ');
+			}
 			printf("|");
 			off++;
 		}
@@ -260,14 +268,24 @@ editQuery(q)
 	char	*q;
 {
 	char	*filename,
+		*editor,
 		combuf[80];
 	int	fd;
 
 	filename = tmpnam(NULL);
 	fd = open(filename,O_CREAT | O_WRONLY, 0777);
+	editor = (char *)getenv("VISUAL");
+	if (!editor)
+	{
+		editor = (char *)getenv("EDITOR");
+	}
+	if (!editor)
+	{
+		editor = "vi";
+	}
 	write(fd,q,strlen(q));
 	close(fd);
-	sprintf(combuf,"vi %s",filename);
+	sprintf(combuf,"%s %s",editor,filename);
 	system(combuf);
 	fd = open(filename,O_RDONLY, 0777);
 	bzero(q,2048);
