@@ -16,11 +16,17 @@
 */
 
 
+#if defined(__STDC__) || defined(__cplusplus)
+#  define __P(x)	x
+#else
+#  define __P(x)	()
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-typedef	char	** m_row;
+typedef	unsigned char	** m_row;
 
 typedef struct field_s {
 	char	*name,
@@ -59,22 +65,6 @@ typedef struct result_s {
 #define	msqlNumFields(res) res->numFields
 
 
-
-#ifdef NOTDEF
-	extern	char msqlErrMsg[];
-	int	msqlQuery();
-	int	msqlClose();
-	int	msqlSelectDB();
-	int	msqlConnect();
-	m_row	msqlFetchRow();
-	m_field	*msqlFetchField();
-	m_result *msqlListDBs();
-	m_result *msqlListTables();
-	m_result *msqlListFields();
-	m_result *msqlStoreResult();
-#endif
-
-
 #define INT_TYPE	1
 #define CHAR_TYPE	2
 #define REAL_TYPE	3
@@ -93,25 +83,25 @@ typedef struct result_s {
 */
 #ifndef _MSQL_SERVER_SOURCE
 	extern  char msqlErrMsg[];
-	int 	msqlConnect();
-	int 	msqlSelectDB();
-	int 	msqlQuery();
-	int 	msqlCreateDB();
-	int 	msqlDropDB();
-	int 	msqlShutdown();
-	int 	msqlReloadAcls();
+	int 	msqlConnect __P((char *));
+	int 	msqlSelectDB __P((int, char*));
+	int 	msqlQuery __P((int, char*));
+	int 	msqlCreateDB __P((int, char*));
+	int 	msqlDropDB __P((int, char*));
+	int 	msqlShutdown __P((int));
+	int 	msqlReloadAcls __P((int));
 	int 	msqlGetProtoInfo();
 	char 	*msqlGetServerInfo();
 	char 	*msqlGetHostInfo();
-	void	msqlClose();
-	void 	msqlDataSeek();
-	void 	msqlFieldSeek();
-	void 	msqlFreeResult();
-        m_row   msqlFetchRow();
-	m_field	*msqlFetchField();
-	m_result *msqlListDBs();
-	m_result *msqlListTables();
-	m_result *msqlListFields();
+	void	msqlClose __P((int));
+	void 	msqlDataSeek __P((m_result*, int));
+	void 	msqlFieldSeek __P((m_result*, int));
+	void 	msqlFreeResult __P((m_result*));
+        m_row   msqlFetchRow __P((m_result*));
+	m_field	*msqlFetchField __P((m_result *));
+	m_result *msqlListDBs __P((int));
+	m_result *msqlListTables __P((int));
+	m_result *msqlListFields __P((int, char*));
 	m_result *msqlStoreResult();
 #endif
 
