@@ -155,6 +155,7 @@ static symtab_t symtab[16][16] = {
 		{ 0,		0}
 	},
 	{ /* 6 */
+		{ "NULL",	token(NULLSYM)},
 		{ 0,		0}
 	},
 	{ /* 7 */
@@ -481,6 +482,15 @@ int yylex()
 			/* State 7: Incomplete real number */
 			CASE(7)
 				c = yyGet();
+
+		                /* Analogy Start */
+                                if(c == 'e' || c == 'E')
+                                {
+                                        state = 15;
+                                        break;
+                                }
+                		/* Analogy End   */
+ 
 				if (isdigit(c))
 				{
 					state = 7;
@@ -566,6 +576,46 @@ int yylex()
 					state = 14;
 				}
 				break;
+
+			/* Analogy Start */
+                        /* State 15: Exponent Sign in Scientific Notation */
+                        CASE(15)
+                                c = yyGet();
+                                if(c == '-' || c == '+')
+                                {
+                                      state = 16;
+                                      break;
+                                }
+                                state = 999;
+                                break;
+
+                        /* State 16: Exponent Value-first digit in Scientific 
+			** Notation */
+                        CASE(16)
+                                c = yyGet();
+                                if (isdigit(c))
+                                {
+                                        state = 17;
+                                        break;
+                                }
+                                state = 999;  	/* if no digit, then token 
+						** is unknown */
+                                break;
+
+                        /* State 17: Exponent Value in Scientific Notation */
+                        CASE(17)
+                                c = yyGet();
+                                if (isdigit(c))
+                                {
+                                        state = 17;
+                                        break;
+                                }
+                                state = 8;     	/* At least 1 exponent 
+						** digit was required */
+                                break;
+			/* Analogy End */
+
+
 				
 
 			/* State 999 : Unknown token.  Revert to single char */
