@@ -23,7 +23,7 @@
 
 
 
-#define MAX_FIELDS	40		/* Max fields per query */
+#define MAX_FIELDS	50		/* Max fields per query */
 #define MAX_CON		24		/* Max connections */
 #define BUF_SIZE	(256*1024)	/* Read buf size if no mmap() */
 #define NAME_LEN	20		/* Field/table name length */
@@ -64,6 +64,11 @@ typedef struct val_s {
 } val_t;
 
 
+typedef struct tname_s {
+	char	name[NAME_LEN + 1],
+		cname[NAME_LEN + 1];
+	struct	tname_s *next;
+} tname_t;
 
 /* 
 ** Internal field list element
@@ -123,9 +128,10 @@ typedef struct order_s {
 */
 typedef struct cache_s {		
 	char	DB[NAME_LEN + 1],
+		cname[NAME_LEN + 1],
 		table[NAME_LEN + 1],
-		resInfo[4 * NAME_LEN], /* used for debugging info */
-		*rowBuf,
+		resInfo[4 * NAME_LEN]; /* used for debugging info */
+	u_char	*rowBuf,
 		*keyBuf;
 	int	age,
 		stackFD,
