@@ -55,12 +55,12 @@ field_t	*fieldHead = NULL,
 
 order_t	*orderHead = NULL;
 
-tlist_t	*tableHead = NULL;
+tname_t	*tableHead = NULL;
 
 static	cond_t	*condTail = NULL;
 static	field_t	*fieldTail = NULL;
 static	order_t	*orderTail = NULL;
-static	tlist_t	*tableTail = NULL;
+static	tname_t	*tableTail = NULL;
 static 	int	havePriKey = 0;
 
 
@@ -88,7 +88,7 @@ msqlClean()
 	register field_t	*curField, *tmpField;
 	register cond_t		*curCond, *tmpCond;
 	register order_t 	*curOrder, *tmpOrder;
-	register tlist_t	*curTable, *tmpTable;
+	register tname_t	*curTable, *tmpTable;
 
 	msqlTrace(TRACE_IN,"msqlClean()");
 	command = 0;
@@ -147,7 +147,7 @@ msqlClean()
 	condHead = condTail = (cond_t *) NULL;
 	fieldHead = fieldTail = lastField = (field_t *) NULL;
 	orderHead = orderTail = (order_t *) NULL;
-	tableHead = tableTail = (tlist_t *) NULL;
+	tableHead = tableTail = (tname_t *) NULL;
 
 	msqlBackendClean();
 
@@ -286,7 +286,7 @@ val_t *msqlCreateValue(textRep,type,tokLen)
 			break;
 
 		case REAL_TYPE:
-			sscanf((char *)textRep ,"%lf",&new->val.realVal);
+			sscanf((char *)textRep ,"%lg",&new->val.realVal);
 			break;
 	}
 	msqlTrace(TRACE_OUT,"msqlCreateValue()");
@@ -601,16 +601,28 @@ msqlAddOrder(ident,dir)
 
 
 
-msqlAddTable(name)
-	char	*name;
+msqlAddTable(name,alias)
+	char	*name,
+		*alias;
 {
-	register tlist_t	*new;
+	register tname_t	*new;
 
 	msqlTrace(TRACE_IN,"msqlAddTable()");
 
-	new = (tlist_t *)malloc(sizeof(tlist_t));
-	(void)strcpy(new->name,name);
-	(void)free(name);
+	new = (tname_t *)malloc(sizeof(tname_t));
+	if (alias)
+	{
+		(void)strcpy(new->name,alias);
+		(void)strcpy(new->cname,name);
+		(void)free(name);
+		(void)free(alias);
+	}
+	else
+	{
+		(void)strcpy(new->name,name);
+		*(new->cname) = 0;
+		(void)free(name);
+	}
 	if (!tableHead)
 	{
 		tableHead = tableTail = new;
