@@ -50,6 +50,7 @@
 #include "common/debug.h"
 
 #include "msql_priv.h"
+#include "errmsg.h"
 
 
 
@@ -142,8 +143,12 @@ sendOK(fd)
 initServer()
 {
 	int	sock,
+		tcpPort,
 		addrLen;
 	struct	sockaddr_in	IPaddr;
+	struct	servent		*serv_ptr;
+	char	*unixPort,
+		*envVar;
 
 #ifdef HAVE_SYS_UN_H
 	struct	sockaddr_un	UNIXaddr;
@@ -152,7 +157,16 @@ initServer()
 	/*
 	** Create an IP socket
 	*/
-	msqlDebug(MOD_GENERAL,"IP Socket is %d\n",MSQL_PORT);
+	tcpPort = MSQL_PORT;
+	if ((serv_ptr = getservbyname("msql", "tcp")))
+	{
+		tcpPort = serv_ptr->s_port;
+	}
+	if ((envVar = getenv("MSQL_TCP_PORT")))
+	{
+		tcpPort = atoi(envVar);
+	}
+	msqlDebug(MOD_GENERAL,"IP Socket is %d\n",tcpPort);
 	IPsock = socket(AF_INET, SOCK_STREAM, 0);
 	if (IPsock < 0)
 	{
@@ -162,7 +176,7 @@ initServer()
 	(void)bzero(&IPaddr, sizeof(IPaddr));
 	IPaddr.sin_family = AF_INET;
 	IPaddr.sin_addr.s_addr = htonl(INADDR_ANY);
-	IPaddr.sin_port = htons(MSQL_PORT);
+	IPaddr.sin_port = htons(tcpPort);
 	if (bind(IPsock, (struct sockaddr *)&IPaddr, sizeof(IPaddr)) < 0)
 	{
 		perror("Can't start server : IP Bind ");
@@ -174,7 +188,13 @@ initServer()
 	/*
 	** Create the UNIX socket
 	*/
-	msqlDebug(MOD_GENERAL,"UNIX Socket is %s\n",MSQL_UNIX_ADDR);
+	unixPort = MSQL_UNIX_ADDR;
+	if ((envVar = getenv("MSQL_UNIX_PORT")))
+	{
+		unixPort = envVar;
+	}
+	
+	msqlDebug(MOD_GENERAL,"UNIX Socket is %s\n",unixPort);
 	UNIXsock = socket(AF_UNIX, SOCK_STREAM, 0);
 	if (UNIXsock < 0)
 	{
@@ -183,8 +203,8 @@ initServer()
 	}
 	(void)bzero(&UNIXaddr, sizeof(UNIXaddr));
 	UNIXaddr.sun_family = AF_UNIX;
-	strcpy(UNIXaddr.sun_path, MSQL_UNIX_ADDR);
-	unlink(MSQL_UNIX_ADDR);
+	strcpy(UNIXaddr.sun_path, unixPort);
+	unlink(unixPort);
 	if (bind(UNIXsock, (struct sockaddr *)&UNIXaddr, sizeof(UNIXaddr)) < 0)
 	{
 		perror("Can't start server : UNIX Bind ");
@@ -482,7 +502,7 @@ main(argc,argv)
 			if (numCons > MAX_CON)
 			{
 				numCons--;
-				sendError(newSock,"Too many connections");
+				sendError(newSock,CON_COUNT_ERROR);
 				shutdown(newSock,2);
 				close(newSock);
 				continue;
@@ -513,8 +533,7 @@ main(argc,argv)
 				    AF_INET);
 				if (!hp)
 				{
-					sendError(newSock,
-					"Can't get hostname for your address");
+					sendError(newSock, BAD_HOST_ERROR);
 					error = 1;
 					shutdown(newSock,2);
 					close(newSock);
@@ -549,7 +568,7 @@ main(argc,argv)
 				writePkt(newSock);
 				if (readPkt(newSock) <=0)
 				{
-					sendError(newSock,"Bad handshake");
+					sendError(newSock,HANDSHAKE_ERROR);
 					shutdown(newSock,2);
 					close(newSock);
 					conArray[newSock].host = NULL;
@@ -602,8 +621,8 @@ main(argc,argv)
 					dbname, conArray + comSock);
 				if(conArray[comSock].access == NO_ACCESS)
 				{
-					sendError(comSock,
-						"Access to database denied");
+					sendError(comSock, 
+						ACCESS_DENIED_ERROR);
 					break;
 				}
 				if (msqlInit(dbname) < 0)
@@ -622,8 +641,7 @@ main(argc,argv)
 			    case QUERY:
 				if (!conArray[comSock].db)
 				{
-					sendError(comSock,
-						"No Database Selected");
+					sendError(comSock,NO_DB_ERROR);
 					break;
 				}
 				curSock = comSock;
@@ -648,8 +666,7 @@ main(argc,argv)
 				setProcTitle("Table List");
 				if (!conArray[comSock].db)
 				{
-					sendError(comSock,
-						"No Database Selected");
+					sendError(comSock, NO_DB_ERROR);
 					break;
 				}
 				curSock = comSock;
@@ -660,8 +677,7 @@ main(argc,argv)
 				setProcTitle("Field List");
 				if (!conArray[comSock].db)
 				{
-					sendError(comSock,
-						"No Database Selected");
+					sendError(comSock,NO_DB_ERROR);
 					break;
 				}
 				cp=(char *)strtok(packet+2,
@@ -691,7 +707,7 @@ main(argc,argv)
 				setProcTitle("Create DB");
 				if (!msqlCheckLocal(conArray + comSock))
 				{
-					sendError(comSock,"Permission denied");
+					sendError(comSock,PERM_DENIED_ERROR);
 					break;
 				}
 				cp=(char *)strtok(packet+2,
@@ -704,7 +720,7 @@ main(argc,argv)
 				setProcTitle("Drop DB");
 				if (!msqlCheckLocal(conArray + comSock))
 				{
-					sendError(comSock,"Permission denied");
+					sendError(comSock,PERM_DENIED_ERROR);
 					break;
 				}
 				cp=(char *)strtok(packet+2,
@@ -717,7 +733,7 @@ main(argc,argv)
 				setProcTitle("Reload ACL");
 				if (!msqlCheckLocal(conArray + comSock))
 				{
-					sendError(comSock,"Permission denied");
+					sendError(comSock,PERM_DENIED_ERROR);
 					break;
 				}
 				(void)sprintf(packet,"-100:\n");
@@ -729,7 +745,7 @@ main(argc,argv)
 				setProcTitle("Shutdown");
 				if (!msqlCheckLocal(conArray + comSock))
 				{
-					sendError(comSock,"Permission denied");
+					sendError(comSock,PERM_DENIED_ERROR);
 					break;
 				}
 				sprintf(packet,"-100:\n");
@@ -739,8 +755,7 @@ main(argc,argv)
 				break;
 
 			    default:
-				sendError(comSock,
-					"Unknown command");
+				sendError(comSock, UNKNOWN_COM_ERROR);
 				break;
 			}
 			msqlDebug(MOD_GENERAL,"Command Processed!\n");
