@@ -165,21 +165,19 @@ int getTableStructure(table)
 	}
 
 	printf("\n#\n# Table structure for table '%s'\n#\n",table);
-	sprintf(insert_pat, "INSERT INTO %s \n  (", table);
+	sprintf(insert_pat, "INSERT INTO %s VALUES (", table);
 	printf("CREATE TABLE %s (\n", table);
 
 	while(mf=msqlFetchField(tableRes)) 
 	{
-		if (!init ) 
-		{
-			strcat(insert_pat, ",");
-			printf(",\n");
-		}
-		else
+		if (init)
 		{
 			init = 0;
 		}
-		strcat(insert_pat, mf->name);
+		else
+		{
+			printf(",\n");
+		}
 		printf("  %s ", mf->name);
 		switch(mf->type) 
 		{
@@ -203,7 +201,6 @@ int getTableStructure(table)
 		if(IS_PRI_KEY(mf->flags) )
 			printf(" PRIMARY KEY");
 	}
-	strcat(insert_pat, ")\n  VALUES\n  (");
 	printf("\n) \\g\n\n");
 	numFields = msqlNumFields(tableRes);
 	msqlFreeResult(tableRes);
@@ -264,18 +261,25 @@ void dumpTable(numFields,table)
 				printf(",");
 			else
 				init=0;
-			if (field->type == CHAR_TYPE)
+			if (row[i])
 			{
-				tmp = escapeText(row[i]);
-				printf("\'%s\'", tmp);
-				free(tmp);
+				if (field->type == CHAR_TYPE)
+				{
+					tmp = escapeText(row[i]);
+					printf("\'%s\'", tmp);
+					free(tmp);
+				}
+				else
+				{
+					printf("%s", row[i]);
+				}
 			}
 			else
 			{
-				printf("%s", row[i]);
+				printf("NULL");
 			}
 		}
-		printf(")\n  \\g\n");
+		printf(")\\g\n");
 	}
 }
 
@@ -363,7 +367,7 @@ main(argc, argv)
 	}
 	
 
-	printf("#\n# mSQLdump output\n#\n");
+	printf("#\n# mSQL Dump  (requires mSQL-1.0.6 or better)\n#\n");
 	printf("# Host: %s    Database: %s\n",
 	    host ? host : "localhost", database);
 	printf("#--------------------------------------------------------\n\n");
